package forgepb

// functions to import and export the protobuf
// data to and from config files

import (
	"errors"
	"os"
	"path/filepath"

	"go.wit.com/log"
	"google.golang.org/protobuf/proto"
)

// writes out the cluster information it seperate files
// to make it humanly possible to hand edit things as needed
func (m *Repos) ConfigSave() error {
	data, err := m.Marshal()
	if err != nil {
		log.Info("proto.Marshal() failed len", len(data), err)
		return err
	}
	log.Info("proto.Marshal() worked len", len(data))
	configWrite("forge.pb", data)

	s := m.FormatTEXT()
	configWrite("forge.text", []byte(s))
	return nil
}

func (m *Repos) ConfigLoad() error {
	if m == nil {
		return errors.New("It's not safe to run ConfigLoad() on a nil ?")
	}

	if data, err := loadFile("forge.pb"); err == nil {
		if err = proto.Unmarshal(data, m); err != nil {
			log.Warn("broken forge.pb config file")
			return err
		}
	} else {
		return err
	}
	return nil
}

func loadFile(filename string) ([]byte, error) {
	homeDir, err := os.UserHomeDir()
	p := filepath.Join(homeDir, ".config/forge")
	fullname := filepath.Join(p, filename)
	data, err := os.ReadFile(fullname)
	if err != nil {
		// log.Info("open config file :", err)
		return nil, err
	}
	return data, nil
}

func configWrite(filename string, data []byte) error {
	homeDir, err := os.UserHomeDir()
	p := filepath.Join(homeDir, ".config/forge")
	fname := filepath.Join(p, filename)
	cfgfile, err := os.OpenFile(fname, os.O_RDWR|os.O_CREATE, 0666)
	defer cfgfile.Close()
	if err != nil {
		log.Warn("open config file :", err)
		return err
	}
	cfgfile.Write(data)
	return nil
}
